@@ -19,5 +19,6 @@ class ReservationOutputWriter(object):
         self.session.WriteMessageToReservationOutput(self.resevation_id, '<font color="#f48342">WARNING: %s</font>'%msg)
 
     def _remove_illegal_chars(self, str):
-        rx = re.compile(u'\x00')
+        rx = re.compile('\x00')
+        str = str if not getattr(str, "decode", False) else str.decode()  # can be a bytes-like object
         return rx.sub('', str)
\ No newline at end of file
